---
search:
  exclude: true
---
# コード例

[リポジトリ](https://github.com/openai/openai-agents-python/tree/main/examples) の examples セクションでは、 SDK のさまざまなサンプル実装をご覧いただけます。これらのコード例は、異なるパターンや機能を示す複数のカテゴリーに整理されています。

## カテゴリー

- **[agent_patterns](https://github.com/openai/openai-agents-python/tree/main/examples/agent_patterns)** :
  このカテゴリーでは、一般的な エージェント 設計パターンを紹介しています。

    - 決定論的ワークフロー  
    - ツールとしての エージェント  
    - エージェント の並列実行  

- **[basic](https://github.com/openai/openai-agents-python/tree/main/examples/basic)** :
  ここでは、 SDK の基本的な機能を取り上げています。

    - 動的な system prompt  
    - ストリーミング 出力  
    - ライフサイクルイベント  

- **[tool examples](https://github.com/openai/openai-agents-python/tree/main/examples/tools)** :
  Web 検索 や ファイル検索 など、 OpenAI がホストするツールの実装方法と、それらを エージェント に統合する方法を学べます。

- **[model_providers](https://github.com/openai/openai-agents-python/tree/main/examples/model_providers)** :
  OpenAI 以外のモデルを SDK で利用する方法を探ります。

- **[handoffs](https://github.com/openai/openai-agents-python/tree/main/examples/handoffs)** :
  エージェント のハンドオフの実践的な例をご覧いただけます。

- **[mcp](https://github.com/openai/openai-agents-python/tree/main/examples/mcp)** :
  MCP を使用して エージェント を構築する方法を学びます。

- **[customer_service](https://github.com/openai/openai-agents-python/tree/main/examples/customer_service)** と **[research_bot](https://github.com/openai/openai-agents-python/tree/main/examples/research_bot)** :
  実際のユースケースを想定した、より作り込まれた 2 つの例

    - **customer_service** : 航空会社向けカスタマーサービスシステムの例。  
    - **research_bot** : シンプルな ディープリサーチ クローン。  

- **[voice](https://github.com/openai/openai-agents-python/tree/main/examples/voice)** :
  TTS と STT モデルを利用した音声 エージェント の例をご覧ください。

- **[realtime](https://github.com/openai/openai-agents-python/tree/main/examples/realtime)** :
  SDK を使って Realtime API の体験を構築する方法を示す例。